WikidataAligner
===============

.. currentmodule:: bioregistry.align

.. autoclass:: WikidataAligner
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~WikidataAligner.curation_header
      ~WikidataAligner.key

   .. rubric:: Methods Summary

   .. autosummary::

      ~WikidataAligner.get_curation_row
      ~WikidataAligner.getter
      ~WikidataAligner.prepare_external

   .. rubric:: Attributes Documentation

   .. autoattribute:: curation_header
   .. autoattribute:: key

   .. rubric:: Methods Documentation

   .. automethod:: get_curation_row
   .. automethod:: getter
   .. automethod:: prepare_external
